@@ -119,7 +119,6 @@ static void gsm_color_button_drag_data_received (GtkWidget * widget,
                                                  GSMColorButton *
                                                  color_button);
 
-
 static guint color_button_signals[LAST_SIGNAL] = { 0 };
 
 static const GtkTargetEntry drop_types[] = { {"application/x-color", 0, 0} };
@@ -194,7 +193,6 @@ gsm_color_button_class_init (GSMColorButtonClass * klass)
 
 }
 
-
 static cairo_surface_t *
 fill_image_buffer_from_file (cairo_t *cr, const char *filePath)
 {
@@ -223,7 +221,6 @@ fill_image_buffer_from_file (cairo_t *cr, const char *filePath)
     return tmp_surface;
 }
 
-
 static void
 render (GtkWidget * widget)
 {
@@ -506,12 +503,11 @@ gsm_color_button_drag_data_received (GtkWidget * widget,
         return;
     }
 
-
     dropped = (guint16 *) gtk_selection_data_get_data (selection_data);
 
-    priv->color.red = dropped[0];
-    priv->color.green = dropped[1];
-    priv->color.blue = dropped[2];
+    priv->color.red =   ((double) dropped[0]) / 65535.0;
+    priv->color.green = ((double) dropped[1]) / 65535.0;
+    priv->color.blue =  ((double) dropped[2]) / 65535.0;
 
     gtk_widget_queue_draw (GTK_WIDGET(color_button));
 
@@ -522,7 +518,6 @@ gsm_color_button_drag_data_received (GtkWidget * widget,
     g_object_thaw_notify (G_OBJECT (color_button));
 }
 
-
 static void
 set_color_icon (GdkDragContext * context, GdkRGBA * color)
 {
@@ -565,16 +560,15 @@ gsm_color_button_drag_data_get (GtkWidget * widget,
 
     priv = gsm_color_button_get_instance_private (color_button);
 
-    dropped[0] = priv->color.red;
-    dropped[1] = priv->color.green;
-    dropped[2] = priv->color.blue;
+    dropped[0] = (guint16) (65535.0 * priv->color.red);
+    dropped[1] = (guint16) (65535.0 * priv->color.green);
+    dropped[2] = (guint16) (65535.0 * priv->color.blue);
     dropped[3] = 65535;        // This widget doesn't care about alpha
 
     gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data),
                             16, (guchar *) dropped, 8);
 }
 
-
 static void
 gsm_color_button_init (GSMColorButton * color_button)
 {
@@ -751,7 +745,6 @@ gsm_color_button_released (GtkWidget * widget, GdkEventButton * event)
     return 0;
 }
 
-
 static gboolean
 gsm_color_button_enter_notify (GtkWidget * widget, GdkEventCrossing * event)
 {
