@@ -244,7 +244,6 @@ GtkWidget *
 proctable_new (ProcData * const procdata)
 {
     GtkWidget *proctree;
-    GtkWidget *scrolled;
     GtkTreeStore *model;
     GtkTreeSelection *selection;
     GtkTreeViewColumn *column;
@@ -287,11 +286,6 @@ proctable_new (ProcData * const procdata)
 
     gint i;
 
-    scrolled = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                    GTK_POLICY_AUTOMATIC,
-                                    GTK_POLICY_AUTOMATIC);
-
     model = gtk_tree_store_new (NUM_COLUMNS,
                                 G_TYPE_STRING,              /* Process Name */
                                 G_TYPE_STRING,              /* User         */
@@ -518,8 +512,6 @@ proctable_new (ProcData * const procdata)
         }
     }
 
-    gtk_container_add (GTK_CONTAINER (scrolled), proctree);
-
     procdata->tree = proctree;
 
     procman_get_tree_state (procdata->settings, proctree, "proctree");
@@ -559,7 +551,7 @@ proctable_new (ProcData * const procdata)
     g_signal_connect (G_OBJECT (model), "sort-column-changed",
                       G_CALLBACK (cb_sort_changed), procdata);
 
-    return scrolled;
+    return proctree;
 }
 
 
